# Installation

## Stable release

To install Supermetrics client for Python., run this command in your terminal:

```sh
uv add supermetrics
```

Or if you prefer to use `pip`:

```sh
pip install supermetrics
```

## From source

The source files for Supermetrics client for Python. can be downloaded from the [GitHub repo](https://github.com/supermetrics-public/supermetrics-python-sdk).

You can either clone the public repository:

```sh
git clone git://github.com/supermetrics-public/supermetrics-python-sdk
```

Or download the [tarball](https://github.com/supermetrics-public/supermetrics-python-sdk/tarball/main):

```sh
curl -OJL https://github.com/supermetrics-public/supermetrics-python-sdk/tarball/main
```

Once you have a copy of the source, you can install it with:

```sh
cd supermetrics
uv pip install .
```
